
a Python interface to NAMD
http://www.ks.uiuc.edu/Research/namd/

..
   master

.. image:: https://img.shields.io/pypi/v/namdtools
   :target: https://pypi.org/project/namdtools/


note that this package is **still in development**
at this stage, I'm only building thing as they come to mind  
version 1.0 will be the first major release  
until then, consider this code heavily volatile

yet, install simply by calling `pip install namdtools` or `pip install --pre namdtools` for the latest development
release.

we endeavor to follow https://scikit-learn.org/stable/developers/performance.html

similar packages:
https://github.com/sunhwan/NAMD-replica
https://github.com/bio-phys/MDBenchmark
https://github.com/radakb/pynamd/

